 

| 2014년 국정감사 산업통상자원위원회 |
| :--- |

업  무  현  황

2014. 10.

산업통상자원부

 

| 목   차 |
| :--- |

I. 일반 현황	1

 1. 기능 및 조직	2

 2. 예산 현황	4

 3. 주요 정부입법 추진 계획	5

 4. 산하 공공기관 현황	7

II. 2013년 국감 지적사항 조치 결과	 8

III. 최근 경제동향 및 평가	13

IV. 주요 현안 및 정책과제	16

 1. 수출과 내수의 균형잡힌 성장 추진	17

    중소･중견기업 수출 지원 강화	18

    규제개혁 및 투자활성화	20

    지역경제 활력 제고	22

 2. 창조 혁신형 新성장동력 육성	24

    미래 성장 新산업 육성	25

    창조적 산업생태계 구축	28

 3. 개방형 통상정책을 통한 경제협력 활성화	35

    대외개방형 통상정책 지속 추진 	36

    글로벌 비즈니스를 위한 맞춤형 경제협력 활성화	38

 4. 안정적인 에너지시스템 구축	39

    에너지신산업 육성	40

    안전 최우선의 원전정책 추진	42

    에너지공기업 등 공공기관에 대한 개혁 지속추진	44

    지속가능한 에너지정책 추진	45

| I. 일반 현황 |
| :--- |

 

| 1 |  | 기능 및 조직 |
| :--- | :--- | :--- |

□ 조직 : 1·2차관, 본부(1차관보, 6실, 2국, 20관, 2단, 75과), 소속기관(7개)

 ㅇ 본부 : 2차관, 1차관보, 6실, 2국, 18관, 2단, 75과

  - 기획․직속 분야 : 기획조정실, 감사관 등 4관 7과

  - 무역․투자 분야 : 무역투자실 3관 11과

  - 산업정책 분야 : 산업정책실 3관 13과

  - 산업기반 분야 : 산업기반실 3관 11과

  - 통상 분야 : 통상정책국․협력국 2국 2심의관 9과, 

                통상교섭실 2관 1단 8과

  - 에너지․자원 분야 : 에너지자원실 3관 1단 16과

 ㅇ 소속기관* : 2위원회, 2원, 2소, 1기획단

    * 무역위원회, 전기위원회, 국가기술표준원, 자유무역지역관리원, 광업등록사무소, 광산보안사무소, 경제자유구역기획단

 

□ 인 원 

 ㅇ 정원 : 1,292명 (본부 855명 + 소속기관 437명*)

    * 소속기관 : 무역위 48명, 전기위 9명, 국표원 219명, 자유무역관리원 80명, 광업등록사무소 33명, 광산보안사무소 33명, 경자단 15명

 ㅇ 현원 : 1,238명 (본부 868명+ 소속기관 370명)

<계급별 정원 및 현원(‘14.9)>

<table>
  <tr>
    <th rowspan="2" colspan="2">구    분</th>
    <th rowspan="2">정
무
직</th>
    <th colspan="2">고공단</th>
    <th rowspan="2">3․4
급</th>
    <th rowspan="2">4
급</th>
    <th rowspan="2">4․5
급</th>
    <th rowspan="2">5
급</th>
    <th rowspan="2">6
급</th>
    <th rowspan="2">7
급</th>
    <th rowspan="2">8
급</th>
    <th rowspan="2">9
급</th>
    <th colspan="2">연구직</th>
    <th rowspan="2">운
영</th>
    <th rowspan="2">임기제</th>
    <th rowspan="2">계</th>
    <th>가</th>
    <th>나</th>
    <th>연구관</th>
  </tr>
  <tr>
    <td>연구사</td>
    <td rowspan="2">본부</td>
    <td>정원</td>
    <td>3</td>
    <td>7</td>
    <td>24</td>
    <td>21</td>
    <td>57</td>
    <td>92</td>
    <td>307</td>
    <td>203</td>
    <td>48</td>
    <td>45</td>
    <td>24</td>
    <td>0</td>
    <td>1</td>
    <td>17</td>
    <td>6</td>
  </tr>
  <tr>
    <td>855</td>
    <td>현원</td>
    <td>3</td>
    <td>8</td>
    <td>21</td>
    <td>16</td>
    <td>80</td>
    <td>66</td>
    <td>345</td>
    <td>181</td>
    <td>76</td>
    <td>31</td>
    <td>8</td>
    <td>5</td>
    <td>0</td>
    <td>23</td>
    <td>5</td>
    <td>868</td>
  </tr>
  <tr>
    <td rowspan="2">소속</td>
    <td>정원</td>
    <td></td>
    <td>2</td>
    <td>6</td>
    <td>1</td>
    <td>30</td>
    <td>8</td>
    <td>86</td>
    <td>121</td>
    <td>33</td>
    <td>18</td>
    <td>6</td>
    <td>43</td>
    <td>26</td>
    <td>57</td>
    <td></td>
    <td>437</td>
  </tr>
  <tr>
    <td>현원</td>
    <td></td>
    <td>2</td>
    <td>5</td>
    <td>4</td>
    <td>21</td>
    <td>5</td>
    <td>71</td>
    <td>47</td>
    <td>50</td>
    <td>16</td>
    <td>5</td>
    <td>63</td>
    <td>37</td>
    <td>44</td>
    <td></td>
    <td>370</td>
    <td rowspan="2">총계</td>
  </tr>
  <tr>
    <td>정원</td>
    <td>3</td>
    <td>9</td>
    <td>30</td>
    <td>22</td>
    <td>87</td>
    <td>100</td>
    <td>393</td>
    <td>324</td>
    <td>81</td>
    <td>63</td>
    <td>30</td>
    <td>43</td>
    <td>27</td>
    <td>74</td>
    <td>6</td>
    <td>1,292</td>
    <td>현원</td>
  </tr>
  <tr>
    <td>3</td>
    <td>10</td>
    <td>26</td>
    <td>20</td>
    <td>101</td>
    <td>71</td>
    <td>416</td>
    <td>228</td>
    <td>126</td>
    <td>47</td>
    <td>13</td>
    <td>68</td>
    <td>37</td>
    <td>67</td>
    <td>5</td>
    <td>1,238</td>
    <td></td>
    <td></td>
  </tr>
  <tr>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
  </tr>
</table>

| 참고 |  | 산업통상자원부 조직도 |
| :--- | :--- | :--- |

![image](assets/BIN0001.bmp)

 

| 2 |  | 예산 현황 |
| :--- | :--- | :--- |

가. 2014년 예산 규모

□ 2014년 예산은 일반회계, 특별회계, 기금 포함 7조 8,965억원

< 2014년도 산업통상자원부 예산 세입․세출 현황 (단위: 억원) >

| 구    분 | 세입(A) | 세출(B) | 수지(A-B) |
| :--- | :--- | :--- | :--- |
| 합  계 | 106,109 | 78,965 | 27,144 |
| 일반회계 | 2,352 | 25,536 | △23,184 |
| 광역지역발전특별회계 | 234 | 13,257 | △13,023 |
| 에너지및자원사업특별회계 | 54,786 | 21,028 | 33,758 |
| 혁신도시건설특별회계 | 437 | - | 437 |
| 전력산업기반기금 | 31,796 | 17,373 | 14,423 |
| 방사성폐기물관리기금 | 16,656 | 1,736 | 14,920 |
| 특정물질사용합리화기금 | 148 | 35 | 113 |

나. 2014년 예산 중점 투입 분야

 불확실한 대외환경과 새로운 통상환경에 선제적 대응

 ㅇ 중소기업의 해외진출 적극 지원, FTA 활용 제고 등 무역 인프라 지속 확충

    * 대한무역투자진흥공사 : (13년) 2,156억원 → (14년) 2,160억원

    * 중소중견기업수출경쟁력강화 : (13년) 340억원 → (14년) 2,160억원

 성장잠재력의 지속적인 확충 및 선순환적 산업생태계 조성

 ㅇ 지역산업은 지역여건에 맞게 육성하고, 노후화된 산업현장도 개선

    * 뿌리산업분야 지원예산 : (13년) 472억원 → (14년) 592억원

    * 산업단지환경조성 : (13년) 110억원 → (14년) 230억원 등

 ㅇ IT 융합 등 고부가가치화를 통한 미래먹거리 창출 

    * 산업부 소관 R&D 예산 : (13년) 31,782억원 → (14년) 32,499억원

 안정적인 에너지․자원 수급역량 확충

 ㅇ 에너지 저소비구조로의 체질개선을 유도하고 에너지 복지사업 확대 추진

    * 농어촌전기공급 등 에너지복지관련사업 : (13년) 3,412억원 → (14년) 3,866억원

 ㅇ 해외자원개발을 내실화하고, 저탄소․친환경 에너지 공급 확대 지속 추진

 

| 3 |  | ‘14년 정부입법 추진 계획 |
| :--- | :--- | :--- |

□ ’14년 정부입법계획에 따른 추진 법률안은 총 22건

 ㅇ 현재 8건 법률안*은 국회에 제출되었으며, 규제개혁 법률안 등 나머지 14건은 금년 중 제출예정

    * 에너지법, 에너지 및 자원사업 특별회계법, 국가표준기본법, 산업기술의 유출방지 및 보호에 관한 법률, 산업표준화법, 산업기술혁신 촉진법, 이러닝산업발전법, 도시가스사업법 

□ 주요 법률안 내용

 ① 에너지법, 에너지특별회계법

  - 에너지 취약계층의 동절기 에너지 지원을 위한 에너지바우처(에너지이용권)를 도입

  - “에너지 및 자원사업”의 범위에 에너지복지 사업 포함 등

 ② 산업기술혁신촉진법

  - 산업기술진흥 및 사업화촉진기금 신설하여, 기술료 사업의 투명성 제고하기 위해 정부기금사업으로 편성

 ③ 국가표준기본법

  - 규제개혁 관련 인증제도간 시험결과 상호인정 근거 마련하여, 기업 인증부담 완화 등

 ④ 산업디자인법

  - 디자인과 제조의 융합기반 마련을 위해 산업디자인의 정의에 기술적 요소를 포함하고 서비스디자인을 산업디자인의 영역에 추가

 ⑤ 자유무역지역법

  - 관리 및 입주, 물품의 반입·반출 규제를 완화하고, 글로벌 배송센터 유치를 위해 부가세 영세율 제도 개선 등

| 참고 |  | 2014년 법률 추진현황 (총22건) |
| :--- | :--- | :--- |

 

<table>
  <tr>
    <th>연번</th>
    <th>단계</th>
    <th>법률안명</th>
    <th>진행현황</th>
    <th>주요 개정 내용</th>
  </tr>
  <tr>
    <td>1</td>
    <td rowspan="8">국회제출
(8)</td>
    <td>산업기술보호법</td>
    <td>국회제출
(6.5)</td>
    <td>▪13년도 정부위원회 정비 계획 후속조치
▪국가핵심기술 보호기반 강화</td>
  </tr>
  <tr>
    <td>2</td>
    <td>산업표준화법</td>
    <td>국회제출
(6.27)</td>
    <td>▪KS 서비스 대상 범위를 확대
▪산업표준개발협력기관 출연근거 마련 등</td>
    <td>3</td>
  </tr>
  <tr>
    <td>산업기술혁신촉진법</td>
    <td>국회제출
(7.30)</td>
    <td>▪‘先연구 後지원’방식 기술개발지원규정 신설
▪산업기술진흥 및 사업화 촉진기금 신설</td>
    <td>4</td>
    <td>에너지법</td>
  </tr>
  <tr>
    <td>국회제출
(8.29)</td>
    <td>▪에너지바우처 제도 근거조항 마련
▪재원 및 추진조직 근거조항 마련</td>
    <td>5</td>
    <td>에너지특별회계법</td>
    <td>국회제출
(8.29)</td>
  </tr>
  <tr>
    <td>▪에너지 및 자원 관련산업의 범위에 에너지 이용권사업(에너지바우처) 포함</td>
    <td>6</td>
    <td>국가표준기본법</td>
    <td>국회제출
(8.29)</td>
    <td>▪부처간 협업확대 및 인증제도간 상호인정
▪기술표준 통상역량 강화 체계 확립 등</td>
  </tr>
  <tr>
    <td>7</td>
    <td>이러닝산업발전법</td>
    <td>국회제출
(10.06)</td>
    <td>▪이러닝인증제도 폐지
▪이러닝진흥위원회 위원 정비 등</td>
    <td>8</td>
  </tr>
  <tr>
    <td>도시가스사업법</td>
    <td>국회제출
(10.10)</td>
    <td>▪천연가스 수입계약 사전통보의무 폐지
▪수출입업자의 조건부등록 취소 규정 폐지 등</td>
    <td>9</td>
    <td rowspan="14">입법추진중
(14)</td>
  </tr>
  <tr>
    <td>제품안전기본법</td>
    <td>법제처
심사</td>
    <td>▪안전성조사 범위 확대 및 결과 공표
▪중대한 사고 발생시 사업자의 보고 의무화 등</td>
    <td>10</td>
    <td>산업디자인진흥법</td>
  </tr>
  <tr>
    <td>차관회의</td>
    <td>▪산업디자인의 범위 서비스 등 확장
▪우수디자인산업표지 벌칙 삭제 등</td>
    <td>11</td>
    <td>전자무역촉진법</td>
    <td>차관회의</td>
  </tr>
  <tr>
    <td>▪위원회정비계획 전자무역위원회 조항 삭제
▪전문서비스업자 등록제 폐지 등</td>
    <td>12</td>
    <td>산업발전법</td>
    <td>법제처
심사</td>
    <td>▪생산성 경영체제 인증제도 폐지
▪한국생산성본부 수익사업 승인권 폐지 등</td>
  </tr>
  <tr>
    <td>13</td>
    <td>석탄산업법</td>
    <td>“</td>
    <td>▪폐광대책비 지원 한도설정 법적 근거 마련
▪석탄산업 사문화, 중복규제 폐지</td>
    <td>14</td>
  </tr>
  <tr>
    <td>외국인투자 촉진법</td>
    <td>“</td>
    <td>▪신고제도 폐지 등 외국인투자 관련 규제 개선
▪예외적 수의계약 과태료 부과 규정 신설 등</td>
    <td>15</td>
    <td>지능형로봇법</td>
  </tr>
  <tr>
    <td>입법예고</td>
    <td>▪로봇품질인증관련 조항 삭제 
▪품질경쟁력 향상을 위한 지원 근거 마련 등</td>
    <td>16</td>
    <td>환경친화 자동차촉진법</td>
    <td>“</td>
  </tr>
  <tr>
    <td>▪환경경영수행 현황자료 제출 삭제
▪허위보고 시 과태료부과 삭제 등</td>
    <td>17</td>
    <td>집단에너지사업법</td>
    <td>“</td>
    <td>▪대체 열공급제도와 보편적 열요금 감면제도  도입
▪사업의 휴업․폐업 조건을 완화</td>
  </tr>
  <tr>
    <td>18</td>
    <td>석유및석유대체연료법</td>
    <td>“</td>
    <td>▪보세구역 내 포괄적 부가가치활동 허용
▪위반자 폐업신고와 관계없이 행정처분 등</td>
    <td>19</td>
  </tr>
  <tr>
    <td>에너지이용합리화법</td>
    <td>“</td>
    <td>▪효율관리기자재와 통합운영 및 대상품목을 축소</td>
    <td>20</td>
    <td>자유무역지역법</td>
  </tr>
  <tr>
    <td>“</td>
    <td>▪입주기업 재고관리의무, 출입제한 완화 
▪국외반출 및 수출신고 간소화 등</td>
    <td>21</td>
    <td>광업법</td>
    <td>“</td>
  </tr>
  <tr>
    <td>▪사업개시 의무 등 폐지
▪지도‧감독 규정 완화, 불필요 규제 통합</td>
    <td>22</td>
    <td>광산보안법</td>
    <td>입안중</td>
    <td>▪광산근로자 의무교육 도입
▪법률내 중복 법령의 정비 등</td>
  </tr>
  <tr>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
  </tr>
  <tr>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
  </tr>
  <tr>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
  </tr>
  <tr>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
  </tr>
</table>

| 4 |  | 산하 공공기관 현황 |
| :--- | :--- | :--- |

□ 공기업 12개, 준정부기관 15개, 기타 공공기관 14개 등 총 41개

< 산업통상자원부 산하 공공기관 >

<table>
  <tr>
    <th>구분</th>
    <th>기관
유형</th>
    <th>세부분류기준</th>
    <th>대 상 기 관</th>
  </tr>
  <tr>
    <td rowspan="3">공
기
업
(12)</td>
    <td colspan="3">자체수입액이 총수입액의 50%이상인 기관</td>
    <td>시장형
(10)</td>
    <td>자산 2조원 이상, 자체수입액이
총수입액의
85% 이상</td>
  </tr>
  <tr>
    <td>한국전력공사, 석유공사, 가스공사,
 지역난방공사, 한국수력원자력㈜, 남동발전㈜,
 남부발전㈜, 동서발전㈜, 서부발전㈜, 중부발전㈜</td>
    <td>준시장형
(2)</td>
    <td>시장형공기업이
아닌 공기업</td>
    <td>석탄공사, 광물자원공사</td>
  </tr>
  <tr>
    <td rowspan="3">준
정부
기관
(15)</td>
    <td colspan="3">자체수입액이 총수입액의 50%미만인 기관</td>
    <td>위탁
집행형
(13)</td>
    <td>정부 정책 사업 
위탁․대행</td>
  </tr>
  <tr>
    <td>․(산업분야) 산업단지공단, 디자인진흥원, 세라믹기술원, 산업기술진흥원, 산업기술평가관리원
․(무역분야) 대한무역투자진흥공사
․(에너지분야) 전기안전공사, 가스안전공사, 
에너지관리공단, 광해관리공단, 전력거래소, 
에너지기술평가원, 석유관리원</td>
    <td>기금
관리형(2)</td>
    <td>기금 관리 위탁</td>
    <td>무역보험공사, 한국원자력환경공단</td>
  </tr>
  <tr>
    <td rowspan="5">기타공공기관
(14)</td>
    <td colspan="3">공기업과 준정부기관을 제외한 기관</td>
    <td colspan="2">한전 자회사 (4)</td>
    <td>전력기술㈜, 한전KDN㈜, 한전KPS㈜, 한전원자력연료㈜</td>
  </tr>
  <tr>
    <td colspan="2">연구지원․교육훈련 (1)</td>
    <td>기초전력연구원</td>
    <td colspan="2">지역난방공사 자회사 (1)</td>
    <td>인천종합에너지㈜</td>
  </tr>
  <tr>
    <td colspan="2">그 밖의 기관 (8)</td>
    <td>㈜강원랜드, 가스기술공사, 표준협회, 전략물자관리원,
한일산업기술협력재단, 원자력문화재단, 로봇산업진흥원, 산업기술시험원</td>
    <td></td>
    <td></td>
  </tr>
  <tr>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
  </tr>
  <tr>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
  </tr>
  <tr>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
  </tr>
  <tr>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
  </tr>
</table>

| II. 국감 지적사항 조치결과 |
| :--- |

가. 개괄

□ 2013년 국정감사에서 지적된 산업통상자원부 소관 시정 및 처리 요구사항은 총 73건으로 48건은 조치 완료, 25건은 추진 중

 ㅇ 기획조정 분야 5건, 산업 분야 23건, 무역투자 및 통상* 분야 5건, 에너지․자원 분야 34건

<table>
  <tr>
    <th rowspan="2"></th>
    <th colspan="2"></th>
    <th></th>
    <th colspan="2"></th>
    <th colspan="2"></th>
    <th colspan="2"></th>
    <th></th>
    <th></th>
    <th>전체</th>
    <th colspan="3">기획조정</th>
    <th colspan="2">산업</th>
    <th colspan="2">무역투자·통상</th>
  </tr>
  <tr>
    <td colspan="3">에너지·자원</td>
    <td>건 수</td>
    <td>73</td>
    <td colspan="3">11</td>
    <td colspan="2">23</td>
    <td colspan="2">5</td>
    <td colspan="3">34</td>
    <td>조치완료</td>
    <td>48</td>
    <td colspan="3">5</td>
    <td colspan="2">15</td>
    <td colspan="2">4</td>
  </tr>
  <tr>
    <td colspan="3">24</td>
    <td>추진 중</td>
    <td>25</td>
    <td colspan="3">6</td>
    <td colspan="2">8</td>
    <td colspan="2">1</td>
    <td colspan="3">10</td>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
  </tr>
  <tr>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
  </tr>
  <tr>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
    <td></td>
  </tr>
</table>

나. 주요 내용

□ 기획조정 분야 (11건)

 ㅇ 공공기관 과다한 복지혜택 개선, 자회사에 일감몰아주기 등 5건 조치 완료, 공공기관 비정규직 무기계약직 전환 등은 추진 중

□ 산업 분야 (23건)

 ㅇ 부품소재산업 투자 방안 마련, 중소기업 기술보호 방안 등 15건은 조치 완료, 노후산단 활성화 등은 지속 추진 중

□ 무역투자․통상 분야 (5건)

 ㅇ 한·중 FTA 관련 의견수렴을 통해 보호방안 마련 등 4건 완료, 개성공단 제품이 FTA 특례조항을 활용하여 수출될 수 있도록 조치 중

□ 에너지․자원 분야 (34건)

 ㅇ 전기요금 현실화, 해외자원개발 관련 제도 개선 등 24건 처리 완료, 사용후핵연료 관리기술 국산화 등은 지속 추진 중

| 참 고 |  | 2013년 국정감사 지적사항 조치 결과 (73건) |
| :--- | :--- | :--- |

<table>
  <tr>
    <th>소관</th>
    <th>지적사항</th>
    <th>처리
결과</th>
  </tr>
  <tr>
    <td rowspan="10">기획조정
(11)</td>
    <td>산하공공기관 과다한 복지혜택에 대한 개선대책 수립</td>
    <td>완료</td>
  </tr>
  <tr>
    <td>산하공공기관 수의계약 통한 자회사 일감 몰아주기 개선방안 수립</td>
    <td>완료</td>
    <td>산하에너지공기업 퇴직자의 관련회사 재취업을 통한 관련 회사간 나눠먹기 근절을 위한 제재방안 수립</td>
  </tr>
  <tr>
    <td>완료</td>
    <td>산하공공기관 방만경영, 도덕적해이, 해외자원개발문제 및 원전비리 문제 개선을 위한 개선대책 마련</td>
    <td>완료</td>
  </tr>
  <tr>
    <td>산하공공기관 비리발생 방지를 위한 감사시스템의 근본적인 개선대책 마련</td>
    <td>완료</td>
    <td>산하 에너지공기업의 임직원 비리에 대한 징계기준 강화</td>
  </tr>
  <tr>
    <td>추진중</td>
    <td>여성의 채용 비율 및 간부 비율이 낮고, 장애인고용도 부진하므로 인사관리차원에서 우대할 수 있는 방안 마련</td>
    <td>추진중</td>
  </tr>
  <tr>
    <td>산하공공기관 비정규직 무기계약직 전환 2015년까지 추진</td>
    <td>추진중</td>
    <td>국가중요시설에 대한 방호체계를 점검하고 사고예방 추진(2건)</td>
  </tr>
  <tr>
    <td>추진중</td>
    <td>EMS관련 허위 자료를 제출한 담당자 징계, 재발방지대책 마련</td>
    <td>추진중</td>
  </tr>
  <tr>
    <td rowspan="13">산업
(23)</td>
    <td>대중소 상생협력 확대를 위한 개선방안 마련(3건)
 - 중소기업 기술탈취, 동반성장정책 제도적 강화, 기술보호 지원법 제정 방안마련 등</td>
    <td>완료</td>
  </tr>
  <tr>
    <td>정부차원의 CSR 관심제고와 관련예산 확대 노력 필요</td>
    <td>완료</td>
    <td>개정된 항공우주산업개발 촉진법 취지에 부합하는 정책집행 필요</td>
  </tr>
  <tr>
    <td>완료</td>
    <td>한공산업개발기본계획을 당초 계획대로 추진 필요</td>
    <td>완료</td>
  </tr>
  <tr>
    <td>부품소재산업 및 핵심소재산업에 대한 장기적․전략적 지원방안 마련</td>
    <td>완료</td>
    <td>섬유패션산업에 대한 정부지원정책방안 수립</td>
  </tr>
  <tr>
    <td>완료</td>
    <td>동대문비즈센터에 대한 실질적 지원방안 마련</td>
    <td>완료</td>
  </tr>
  <tr>
    <td>테크노파크 운영실태 점검 및 개선방안 강구</td>
    <td>완료</td>
    <td>대기업의 중소기업 기술 탈취 방지 등 중소기업 기술 보호 개선방안 마련</td>
  </tr>
  <tr>
    <td>완료</td>
    <td>R&D 사업 관련 개선방안 마련(3건)
 - 연구장비 중복구매문제 방지대책, R&D자금 유용이나 횡령에 대한 제재부가금 활용 방안(2건)
 - 연구장비 공동활용 방안(1건)</td>
    <td>완료
추진중</td>
  </tr>
  <tr>
    <td>지역경제발전관련 개선방안 마련(5건)
 - 연속성 있는 지역정책 추진, 부동산임대업포함 기업 국고보조 대상 포함(2건)
 - 구조고도화사업 개선방안 마련, 지역투자촉진보조금 지역편중 완화, 기반시설 국가예산 지원 방안마련(3건)</td>
    <td>완료
추진중</td>
    <td>유통분야 상생 관련 개선방안 마련(3건)
 - 일본계SSM 규제방안, 상품공급점 규제방안, 대형마트의 지역 기여도 제고방안</td>
  </tr>
  <tr>
    <td>추진중</td>
    <td>산업기술개발장비 중복구매 등 관리부실 개선방안 마련</td>
    <td>추진중</td>
  </tr>
  <tr>
    <td rowspan="5">무역투자․
통상
(5)</td>
    <td>경자구역 외국인 투자기업 입주율 저조, 외국교육기관 유치지원확대 등에 대한 대책 마련</td>
    <td>완료</td>
  </tr>
  <tr>
    <td>중소중견기업의 해외수출 마케팅 지원을 위한 전시산업 육성방안 마련 시행</td>
    <td>완료</td>
    <td>한중FTA 추진과 관련, 농민단체와 사전협의 등 의견수렴 및 취약산업 보호 방안 마련</td>
  </tr>
  <tr>
    <td>완료</td>
    <td>통상기능이 산업부로 온전히 이관될 수 있도록 대응책 마련 시행</td>
    <td>완료</td>
  </tr>
  <tr>
    <td>FTA 특례조항을 활용하여 개성공단 제품이 수출될 수 있도록 노력</td>
    <td>추진중</td>
    <td rowspan="30">에
너
지
․
자원
(34)</td>
  </tr>
  <tr>
    <td>산하공공기관이 부채를 자율적으로 축소해 나갈수 있도록 지도․감독 필요</td>
    <td>완료</td>
    <td>산하 에너지공기업의 도덕적 해이로 인한 투자손실발생에 대한 종합적 대책 수립</td>
  </tr>
  <tr>
    <td>완료</td>
    <td>에너지공기업의 부채급증과 재무건전성 악화에 대한 근본적 대책 마련</td>
    <td>완료</td>
  </tr>
  <tr>
    <td>산하 공공기관의 해외자원개발 투자결정 및 정부지원금 집행에 대한 전문적 실질적 평가방안 마련</td>
    <td>완료</td>
    <td>에너지․전력․원자력 관련 홍보사업을 각 회계․기금별로 통폐합하여 전력산업 홍보 효율성 제고</td>
  </tr>
  <tr>
    <td>완료</td>
    <td>해외자원개발관련 무분별한 투자문제, 수익성 저조문제 등에 대한 개선방안 마련</td>
    <td>완료</td>
  </tr>
  <tr>
    <td>해외자원개발 성공불융자의 융자심사체계 개편 등 실효성 제고 방안 마련</td>
    <td>완료</td>
    <td>대기업의 M&A에까지 국비를 지원할 필요가 없으므로 개선방안 마련</td>
  </tr>
  <tr>
    <td>완료</td>
    <td>에너지기본계획을 정확한 수요예측에 기반하여 수립하고, 국민적 공감대 형성 방안을 강구</td>
    <td>완료</td>
  </tr>
  <tr>
    <td>전력수급계획 관련(3건)
 - 전산모형 최적값을 반영해 최소비용의 원칙에 입각한 설비 계획 필요, 설비효율 개선효과 등을 반영하여 계획수립 작성 필요, 전력수요예측 정확도 향상 필요</td>
    <td>완료</td>
    <td>알뜰주유소의 실효성제고, 품질관리 등을 위한 개선대책 마련</td>
  </tr>
  <tr>
    <td>완료</td>
    <td>석유 전자상거래에 따라 수입만 많아지고 수출에는 도움이 되지 않는 문제 대책 마련</td>
    <td>완료</td>
  </tr>
  <tr>
    <td>천연가스 저렴하게 도입할 방안 마련, 가스사고를 획기적으로 줄일 수 있는 체계 마련</td>
    <td>완료</td>
    <td>한전 발전자회사의 시장형 공기업 지정에 대한 타당성 재검토 및 그 결과 보고</td>
  </tr>
  <tr>
    <td>완료</td>
    <td>마이스터고, 원자력인력양성원 등을 통한 원전기술자 확보방안 마련</td>
    <td>완료</td>
  </tr>
  <tr>
    <td>에너지기본계획 관련, 스마트그리드‧ESS등을 활용한 적극적 수요관리 정책 마련</td>
    <td>완료</td>
    <td>전기요금체계 관련(2건)
 - 전기요금 현실화는 중장기적으로 예측가능한 방향으로 실시, 산업용전기요금 현실화와 함께 초‧중‧고교 전기요금 인하방안 및 누진제 완화방안 등 적극 검토</td>
  </tr>
  <tr>
    <td>완료</td>
    <td>민간발전기에 대해서도 발전기 고장에 따른 추가적인 전력구입비 증가의 책임소재 명확화 필요</td>
    <td>완료</td>
  </tr>
  <tr>
    <td>석탄발전 분야의 R&D 지원 강화 필요</td>
    <td>완료</td>
    <td>원전비리 관련 업체 퇴출에 따른 대체업체 육성방안, 독점기술 보유업체에 대한 대체기업 육성 방안 마련</td>
  </tr>
  <tr>
    <td>완료</td>
    <td>발전사업자 선정 관련(2건)
 - 전력수급계획 수립시 공정하고 투명한 절차를 통해 발전사업자 선정
 - 민간발전사 파산에 따른 사업권 양도가능 규정의 타당성 및 발전사 건설의향 철회시 벌칙부과 필요성에 대해 검토</td>
    <td>완료
추진중</td>
  </tr>
  <tr>
    <td>지방이전 공공기관 사업비 증가가 공공요금 인상으로 이어지지 않도록 관리감독 강화</td>
    <td>추진중</td>
    <td>현재사용중인 EMS에 대해 제3의 외국기관에게 기술검증 의뢰하고 EMS 정상화방안 마련</td>
  </tr>
  <tr>
    <td>추진중</td>
    <td>전력설비 관리 강화를 위해 제3자 검사제도 도입 등 구체적 개선방안 마련</td>
    <td>추진중</td>
  </tr>
  <tr>
    <td>원전 해체 충당금이 적립되지 않으므로 이에 대한 구체적 재원조달 계획 마련</td>
    <td>추진중</td>
    <td>용량가격, 제약비발전정산금 등의 정산금에 대한 제도개선 방안을 마련하여 보고</td>
  </tr>
  <tr>
    <td>추진중</td>
    <td>토륨에 대한 연구‧개발 강화 필요</td>
    <td>추진중</td>
  </tr>
  <tr>
    <td>사용후 핵연료 관리기술의 국산화 방안 연구, 원자력 관련 전문기관과의 협의 강화</td>
    <td>추진중</td>
    <td>가짜 석유제품 제조‧유통, 정량미달 석유판매 등의 근절대책 강구</td>
  </tr>
  <tr>
    <td>추진중</td>
    <td>신재생에너지 보급 확대 정책 실효성 확보를 위해 국가적 콘트롤 타워 설치 등 방안 강구</td>
    <td>추진중</td>
  </tr>
  <tr>
    <td></td>
    <td></td>
    <td></td>
  </tr>
  <tr>
    <td></td>
    <td></td>
    <td></td>
  </tr>
  <tr>
    <td></td>
    <td></td>
    <td></td>
  </tr>
  <tr>
    <td></td>
    <td></td>
    <td></td>
  </tr>
  <tr>
    <td></td>
    <td></td>
    <td></td>
  </tr>
  <tr>
    <td></td>
    <td></td>
    <td></td>
  </tr>
  <tr>
    <td></td>
    <td></td>
    <td></td>
  </tr>
  <tr>
    <td></td>
    <td></td>
    <td></td>
  </tr>
  <tr>
    <td></td>
    <td></td>
    <td></td>
  </tr>
  <tr>
    <td></td>
    <td></td>
    <td></td>
  </tr>
  <tr>
    <td></td>
    <td></td>
    <td></td>
  </tr>
  <tr>
    <td></td>
    <td></td>
    <td></td>
  </tr>
  <tr>
    <td></td>
    <td></td>
    <td></td>
  </tr>
  <tr>
    <td></td>
    <td></td>
    <td></td>
  </tr>
  <tr>
    <td></td>
    <td></td>
    <td></td>
  </tr>
  <tr>
    <td></td>
    <td></td>
    <td></td>
  </tr>
  <tr>
    <td></td>
    <td></td>
    <td></td>
  </tr>
  <tr>
    <td></td>
    <td></td>
    <td></td>
  </tr>
</table>

| III. 최근 경제동향 및 평가 |
| :--- |

| 1 |  | 최근 실물경제 동향 |
| :--- | :--- | :--- |

□ (세계경제) 미국은 완만한 회복세가 지속되고 있으나 유로존, 중국 및 신흥국은 회복세가 부진한 가운데, 경기둔화 우려 상존

 ㅇ 미국은 연초 한파의 영향에서 벗어나, 내수경기 개선으로 2분기 GDP가 큰 폭으로 반등

    * 美 GDP성장률(전기비연율, %) : (‘13.2Q)1.8 (3Q)4.5 (4Q)3.5 ('14.1Q)△2.1 (2Q)4.2

 ㅇ EU는 2분기 GDP 성장률 정체로 경기둔화 우려가 커지고 있고, 일본은 소비세 인상 영향으로 2분기 (-)성장 기록

    * EU GDP성장률(전기비, %) : (‘13.2Q)0.3 (3Q)0.1 (4Q)0.3 ('14.1Q)0.2 (2Q)0.0

    * 日 GDP성장률(전기비, %) : (‘13.2Q)1.0 (3Q)0.2 (4Q)0.2 ('14.1Q)1.6 (2Q)△1.7

 ㅇ 중국은 수출증가와 미니부양책의 영향으로 점진적인 경기 회복 중이나, 부양책 효과의 지속 여부에 대한 우려 상존

    * 中 GDP성장률(전기비, %) : (‘13.2Q)1.8 (3Q)2.3 (4Q)1.7 ('14.1Q)1.5 (2Q)2.0

□ (국내경제) 수출, FDI 등 주요 실물지표를 중심으로 회복세를 이어가고 있으나, 생산과 설비투자는 회복세가 다소 주춤

 ㅇ 수출은 주력품목의 호조세로 양호한 흐름을 유지하고 있으며, FDI는 신고ㆍ도착기준 모두 역대 최대실적 실현중

    * 수출증가율(전년동월비, %): ('14.4)8.9 (5)△1.5 (6)2.5 (7)5.2 (8)△0.2 (9)6.8

    * 3분기누적 FDI(전년동기대비): 신고 148.2억불(37.9%↑), 도착 97.7억불 (50.1%↑) 

 ㅇ 다만, 8월들어 산업생산의 증가세가 둔화되고 설비투자가 감소세로 전환되며 회복세가 다소 주춤

    * 산업생산 증가율(전년동월비, %): ('14.3)2.7 (4)1.4 (5)△0.6 (6)1.7 (7)2.7 (8)0.6

    * 설비투자 증가율(전년동월비, %): ('14.3)7.2 (4)10.7 (5)5.5 (6)2.4 (7)2.8 (8)△9.8

 ㅇ 더딘 회복을 보이던 소비는 최근 증가세가 확대되는 모습

    * 소매판매 증가율(전년동월비, %): ('14.3)2.1 (4)0.2 (5)1.1 (6)1.0 (7)0.6 (8)2.1

| 2 |  | 평가 및 시사점 |
| :--- | :--- | :--- |

□ (평가) 우리 경제는 수출을 중심으로 양호한 성장을 이어왔으나, 생산·투자 등은 회복세가 공고하지 못해 체감경기 다소 약화

 ㅇ 우리 수출은 올 상반기의 엔저 및 원화강세, 중국 경기둔화 등 대내외 위협요인에도 큰 흔들림 없이 꾸준한 성장세를 유지

 ㅇ 다만, 소비·투자 등 둔화된 내수경기의 회복속도가 더디며 국민들이 느끼는 체감경기는 낮은 수준 지속

    * 제조업 BSI업황(한은) : (’14.2)78 (3)81 (4)82 (5)79 (6)77 (7)74 (8)72 (9)74

 ㅇ 엔저심화, 중동지역 정정불안, 미국의 조기 금리인상 가능성 등 하반기 리스크요인도 여전히 상존

□ (시사점) 국민들이 체감할 수 있는 내수경기 회복과 함께, 국내외 불안요인에 대한 대응력 강화 필요 

  ⇒ 대내외 산업환경 변화에 선제적으로 대응하고 새로운 성장 동력을 육성하기 위한 중장기 대책 추진

<table>
  <tr>
    <th></th>
    <th rowspan="2">< 주요 추진 방향 ></th>
    <th></th>
  </tr>
  <tr>
    <td></td>
    <td></td>
    <td colspan="3">① 국민 체감형 경기회복을 위해 수출과 내수의 균형잡힌 성장 추진
 ② 미래 새로운 먹거리 창출을 위한 창조·혁신형 新성장동력 육성
 ③ 우리기업의 해외진출 확대를 위한 개방형 통상정책 강화 및 경제협력 활성화
 ④ 안전하고 효율적인 에너지시스템 구축을 통해 안정적인 에너지 수급 달성</td>
  </tr>
  <tr>
    <td></td>
    <td></td>
    <td></td>
  </tr>
</table>

| IV. 주요 현안 및 정책 과제 |
| :--- |

| 1. 수출과 내수의 균형잡힌 성장 추진 |
| :--- |

| 중소･중견기업 수출 지원 강화   규제개혁 및 투자활성화   지역경제 활력 제고 |
| :--- |

| 1 |  | 중소․중견기업 수출 지원 강화 |
| :--- | :--- | :--- |

가. 추진 현황

□ ‘17년까지 중소․중견기업 1만개 이상을 수출기업화*하기 위해 내수기업의 수출기업화 촉진, 전자상거래 수출 활성화 등 추진

    * 중소․중견 수출기업 수 : (‘13년) 9만개 → (’17년) 10만개 이상

    * 중소․중견 수출기업 당 평균 수출액이 약 200만 달러임을 감안할 때, 200억 달러 이상의 신규 수출이 창출될 것으로 기대

 ㅇ (내수기업의 수출기업화) 유망 내수기업에 퇴직 무역인력을 1:1 매칭하여 맞춤형 지원하는 내수기업의 수출기업화사업 추진(‘14.9월)

    * ‘14년 하반기에는 500개 내수기업을 발굴하여 시범사업에 착수(9.15)

   - 수출시장 및 품목 전문성을 가진 162개 업체를 전문무역상사로 지정(‘14.9월)하여 중소․중견기업의 간접수출을 확대 

   - 통합 무역정보서비스(www.tradenavi.or.kr) 개통(‘14.7월), 수출 첫걸음 희망보험 도입(‘14.9월) 등 수출초보기업 맞춤형 무역인프라 확충

 ㅇ (전자상거래 수출 활성화) 중소․중견기업이 저렴하게 온라인 수출을 활용하도록 수출 專用 온라인 쇼핑몰*(Kmall24) 개통(무역협회, ‘14.6월)

    * Active-X․공인인증서 필요없는 간편결제, 글로벌 온라인 쇼핑몰 동시등록 등 지원

   - 전자상거래 간이 수출신고제도를 신설*(‘14.7월)하고, 국제특송업체(DHL․Fedex)와 단체할인요금을 도입(’14.9월)하여 해외 배송비 절감

    * 수출품목 당 신고항목을 대폭 축소(57개 → 37개)하고, 100건까지 일괄신고 가능

 ㅇ (무역금융 지원 강화) 수출실적이 적어 지원한도가 부족한 수출 급성장 기업에 대한 무역보험 특별지원* 신설(‘14.10월)

    * 연간 3,000억원 한도 내에서 운영하되, 부족시 확대

   - 환변동보험 인수한도 확대(전년도 수출실적의 70~90% → 100%)(‘14.7월), 환율 일일동향 문자서비스 제공(‘14.6월) 등 추진

 ㅇ (FTA 활용역량 제고) ｢FTA 활용내실화 방안｣을 마련․시행(‘14.5월)

   - 업종별 FTA 교육 실시(‘14.6월), 원산지 확인서 제3자 확인제도 전국 시행(’14.8월), FTA 활용지원 가이드북 발간(‘14.6월) 등 추진

나. 향후 계획

□ (내수기업의 수출기업화) ‘15년부터 매년 3~4천개의 유망 내수기업을 발굴하여 수출기업화 사업을 본격 시행

 ㅇ 전문무역상사와 내수기업간 매칭을 위한 온라인 상시 매칭 지원과 지역별 순회상담회 개최(‘14.10~12월)

□ (전자상거래 수출 활성화) 중소․중견기업 상품의 Amazon(美), 淘宝(타오바오，中) 등 글로벌 온라인 쇼핑몰 판매지원 지속 확대*

    * 지원대상 : (‘14년) 1.3천개사․6.5천개상품 → (’17년) 3천개사․1.5만개상품

 ㅇ 전자상거래 세무신고 서류를 간소화․표준화(‘14.12월)하고, 한-중 해상배송 체계를 구축하여 전자상거래 물류 원활화

□ (무역금융 지원 강화) 수출 중소․중견기업에 대한 유동성 지원 등을 강화하기 위해 무역금융 지원 확대*

    * ‘14년 하반기 지원규모 : (당초) 52.6조원 → (확대) 54.3조원 (1.7조원 ↑)

□ (FTA 활용역량 제고) 수출기업의 FTA 원산지 관리역량 강화 지원

 ㅇ 농축수산식품 특화 원산지 관리시스템을 개발․보급(‘14.11월)하고, FTA 컨설팅 및 원산지 관리시스템 보급 확대 지속

| 2 |  | 규제개혁 및 투자활성화 |
| :--- | :--- | :--- |

| 기존 규제 정비 및 주요 덩어리 규제 발굴･개선 추진 |
| :--- |

□ 규제감축 등 규제 전반의 시스템 개편을 적극 추진 중

 ㅇ 전체 경제적규제(940개)의 15%(140개) 감축을 목표로 입법을 추진 중이며, 규제비용총량제* 시범실시 중

    * 신설․강화 규제 도입으로 인한 비용만큼 기존 규제를 폐지․완화 

   - 폐지 외 존치규제에 대해서도 완화․일몰설정 등 품질제고 노력을 강화, 숨겨진 부담으로 작용하는 미등록규제도 적극 정비

    * 안전 등과 관련해서 필요한 규제는 규제정비․총량제 적용 제외

 ㅇ 규제개혁신문고 운영*, 손톱 밑 가시 과제** 등 국민․기업의 규제개선 건의수렴 및 애로 해결을 위한 노력도 지속

    * 총 건의 240건 중 95건 수용(수용률 39.6%(전부처 평균 30.4%), 10.6일 기준)

   ** 총 45개 과제(‘13년∼) : (완료) 43개, (국회법안심의) 1개, (진행중) 1개  

□ 파급력 있는 규제개혁을 위해 주요 덩어리규제 발굴․개선 추진 중

 ㅇ 산업입지, 경자구역․자유무역지역, 인증 등 개선시 기업 체감도를 제고할 수 있는 분야 중심으로 제도 개선    

< 주요 덩어리규제 개선방안 >

 

| 분야 | 주요 개선내용 |
| :--- | :--- |
| ▶ 산업입지 | ▪ 복합용도구역 도입(산업·지원시설 통합배치) ▪ 산단 입주허용업종 확대(고부가 서비스업 위주) |
| ▶ 경자구역·자유무역지역 | ▪ 경자구역 개발계획 변경 네거티브 규제방식 적용 ▪ 자유무역지역 입주방식 간소화 |
| ▶ 인증 | ▪ 소관 32개 인증제도 중 20개 인증 개선*   * 방식: 폐지(이러닝 등), 민간인증 전환(신뢰성 등), KS 통합(로봇 등) 등 |
| ▶ 동북아 오일허브 | ▪ 석유정제업 저장시설 등록요건 완화 ▪ 보세구역 내 부가가치활동 포괄적 허용 |
| ▶ 무역·외국인투자 | ▪ 전시사업자 및 전자무역 전문서비스업 등록제도 폐지 ▪ 외국인직접투자 절차 간소화(변경신고 폐지 등) |
| ▶ 에너지新산업 육성 | ▪ 지능형전력망 사업자 규정 네거티브 방식 전환 ▪ 전력 수요관리 시장 개설, ESS 등 저장전력 거래 허용 |

| 투자 활성화 |
| :--- |

가. 추진 현황

□ (외국인투자) ‘14.1월 대통령 주재 간담회 후속조치 이행 차원에서, 양질‧고부가가치 외투유치 확대를 위한 제도개선*･유치활동** 지속 

    * (고부가가치 투자유치) HQ·R&D센터 인정기준 마련 및 인센티브 제도 구축 (규제완화) 외투절차 간소화, 중복규제 해소 등을 위한 외촉법 개정추진

   ** 미국(차관, ‘14.3월, 바이오, 해양플랜트 등), 유럽(무투실장, ’14.7월, 유럽소재 글로벌기업) 중국(‘14.8월, 식품, 문화컨텐츠, 복합리조트 등) 등  

□ (유턴투자) 유턴법 시행 및 자금, 인력 애로해소를 위한 ’유턴 추가 대책‘을 마련(‘13.12월)하고 국내외 유치활동을 전개

    * ‘12.4월 정부의 ‘유턴 기업 종합지원 대책’ 발표 이후, ’14.9월 기준 66개社가 유턴을 결정하고 지자체와 MOU 체결

□ (경자구역) 개발지연지구 지정해제*(‘14.8월), 유망서비스 산업 육성대책** (‘14.8월) 등을 통해 선택과 집중에 의한 개발 ･투자활성화 방안 마련 

    *  8.5일 지정해제를 통해 경제자유구역 총면적은 428.37㎢에서 335.84㎢로 축소 

    **  외국 의료기관 및 외국인 교육기관 설립 요건 개선 및 체계적 복합리조트 육성방안 수립 등 

나. 향후 계획 

□ (외국인투자) FTA, HQ‧R&D 센터 지원제도 등을 활용하여, 고급기술, 소재부품, HQ 및 R&D 등 분야 및 중국 투자유치*를 확대

    * 유망분야: 식품, 문화컨텐츠, 복합리조트, 패션 등 

□ (유턴투자) 고부가가치화 지원(R&D, 전문 인력 양성 등)을 통해 국내정착 및 경쟁력 강화를 지원하고 추가수요 발굴(소비재 등 유망분야) 

    * 유턴․중기적합업종 전용 R&D('14년 40억원, 중기청), 신발 분야 숙련인력 양성사업(‘14년 6억, 고용부) 등

□ (경자구역) 경제자유구역특별법 및 시행령 개정 등 관련 제도를 정비*하고 제조업 등의 투자유치 활동을 강화

    * 개발사업시행자 자격요건 완화, 단계적 개발 허용범위 확대 (330만㎡→ 200만㎡)

| 3 |  | 지역경제 활력 제고 |
| :--- | :--- | :--- |

가. 추진현황

□ 시ㆍ도 단위 특화산업과 광역권 선도산업 지원을 통해 지역산업 육성과 일자리 창출 촉진(‘14년, 5,572억원)

 ㅇ 지역의 자율․책임을 강화하는 방향으로 지역산업분야 중장기 발전 로드맵 수립

    * ‘시ㆍ도별 지역산업발전계획’ 수립ㆍ확정(제2차 지역경제위원회, ‘14.9.29)

□ 노후 산업단지 재창조를 위한 산업단지 혁신 중점과제* 추가(’14.9월, 산단 50주년 기념식)

    * 스마트·친환경 기반 구축, 입주기업의 연구·혁신 역량 강화, 노후단지 리모델링 신속 추진, 편리하고 안전한 환경 조성 등

 ㅇ 4개 혁신단지* 선정(’14.3월), 7개 산학융합지구 조성․운영 중

    * 구미, 창원, 반월시화, 대불

□ 지역투자보조금을 통해 지방투자 및 고용창출 촉진

 ㅇ 설비투자보조금 지원을 강화*하고, 지원대상업종도 확대**(‘14.1월)

    * 설비투자 보조비율 : 10% → 12% / ** 지역집중유치업종 : 지자체별 4개 → 6개

나. 향후계획

□ 창의‧혁신적 산업을 육성하여 지역경제 활성화

 ㅇ 지역기업 수요와 산업생태계를 기반으로 시·도별 주력산업과 시·도간 협력산업을 선정·육성

    * (주력산업) 총 63개 선정, ‘14년 2,576억원 (협력산업) 총 16개 선정, ’14년 168억원(시범사업)

 ㅇ 지역 대표산업과 혁신자원을 창조경제혁신센터를 중심으로 연계하여 창의적 부가가치를 창출할 수 있도록 육성

    * (대구 예시) 자동차부품, 안경 등 지역 대표산업과 TP 등 혁신인프라를 연계 → 자동차튜닝산업, 패션문화산업으로 아이디어 사업화, 창업 활성화

 ㅇ 지방이전(혁신도시) 공공기관의 구매력·기술 등을 활용하여 새로운 지역산업 육성

    * ‘14년 광주·전남, 강원, 경남, 경북, 충북 등 5개 혁신도시 지원(60억원)

□ 노후 산업단지를 혁신공간으로 재창조

 ㅇ 산단 리모델링 사업의 조속한 추진으로 민관 공동투자 촉진

    * 당초 계획을 1년 앞당겨 ’16년까지 17개 혁신단지 선정 완료(‘14.12월 3개 선정)

   ** 구조고도화사업로 민간기업 보유부지 투자사업 유치 촉진

 ㅇ 산학융합지구 조성 등을 통해 입주기업의 연구․혁신 역량 강화

    * (산학융합지구) ’14.12월 1개 추가 지정(총 8개) → 산단내 연구인력 공급 확대

 ㅇ 부처간 협업하에 정주여건 개선 및 안전관리 강화를 통해 편리하고 안전한 산단 환경 조성

    * 어린이집 확대(’14년 35개 → ‘17년 60개), 합동방재센터 관할 권역 확대 등

 ㅇ 복합용도구역* 도입, 산단내 입주 가능 지식산업업종 확대 등 산업단지 혁신을 뒷받침하기 위한 법·제도 정비

    * 산업․지원․공공시설의 통합 입주를 허용하는 구역

□ 지역투자를 촉진하기 위해 맞춤형 지원 강화

 ㅇ 일자리 창출과 연계성이 큰 설비투자 중심으로 지원 대상을 단계적으로 확대하는 등 보조금 제도 개편(‘15.3월)

    * 보조금 운영의 투명성 제고, 사후관리 체계화 등 사업관리시스템 구축 추진

| 2. 창조 혁신형 新성장동력 육성 |
| :--- |

| 미래 성장 新산업 육성   창조적 산업생태계 구축 |
| :--- |

| 1 |  | 미래 성장 新산업 육성 |
| :--- | :--- | :--- |

| 주력산업과 ICT･SW 융합기반 13대 산업엔진 추진 |
| :--- |

가. 추진 현황

☐ 민간 중심의 추진체계*를 구성하여 13대 산업엔진 발굴 및 ｢제6차 산업기술혁신 5개년 계획｣의 일환으로 산업엔진 프로젝트 발표(’13.12월, 국과심)

    * 6개월간 500여명의 산‧학‧연 전문가가 참여하여 실무 작업

 ㅇ 미래성장동력과 공통되는 6개 과제에 대해서는 미래부와 공동 추진, 그 외 7개 과제는 산업부 단독 과제로 추진 중

 ㅇ 프로젝트별 산‧학‧연 전문가로 추진단 구성(‘14.4월) 

    * 산업부-미래부간 5개 공동책임 분야에 대해 공동 추진단을 구성

       (스마트 자동차, 웨어러블 스마트기기, 맞춤형 웰니스, 지능형반도체, 첨단 미래소재)

☐ First Mover형 新산업생태계 창출을 위한 실행계획 마련(‘14.8월)

 ㅇ 기술개발과 더불어 국제협력, 인프라 구축, 금융, 사업화, 제도개선 등 종합적‧입체적 지원

  - 취약기술에 대해 산학연 공동개발을 추진하고 국제공동연구를 통해 기술확보‧시장진출이 필요한 경우 전략적 국제협력* 병행

    * (예) G2G 협력채널을 활용한 이스라엘-무인기, 노르웨이-북극기술 등 공동개발

  - 인력양성, 연구장비 구축, 표준‧인증 등 기술 인프라 구축 병행 추진

  - 초기시장 창출을 위한 규제해소, 법령 개정 등 제도개선을 추진하고, 신산업 분야의 고급 융합연구인력 양성

 ㅇ 산업생태계 Tree 작성 및 범부처 차원의 통합자원활용 계획 수립

  - 기존 사업을 최대한 활용하되, 부족 부분에 대해 신규사업 추진 및 관계부처 협업을 통해 조기성과 및 재정 효율화 도모

☐ 산업엔진 프로젝트 추진과정에서 파생된 중간성과를 활용하여 즉시 상용화‧제품화할 수 있는 징검다리형 성장동력 발굴

 ㅇ 최종 기술개발前 징검다리 프로젝트로서 현재 수요가 있는 분야에 대해 금년부터 즉시 단기 기술개발 착수 및 핵심 인프라 활용

    * 예) 원양 어군탐지용 무인기(‘18) → 고속-수직이착륙 무인기(’23)  
해양플랜트 심해공학수조 구축으로(‘14.11월 착공) 드릴쉽 시추시스템 실증서비스 개시(’16)

나. 향후 계획 

☐ ‘제조업 혁신 3.0 실행대책’의 주요내용으로 추진

☐ 산업엔진을 지원할 ‘100대 핵심장비 개발 로드맵(’14~’17)’ 수립(‘14.11월)

□ 프로젝트별 사업 수행‧관리체계를 구축하여 본격적 사업 추진 및 지속적 추진사항 점검

| 제조업 혁신 3.0 실행대책 (Action plan) 추진 |
| :--- |

가. 추진 현황

☐ 최근 중국 제조업의 급속한 고도화*, 美․獨 등 선진국의 제조업 스마트화** 추세 등 우리 제조업 환경이 빠르게 변화 중

    * (예) 스마트폰 : 중국 샤오미는 갤럭시 S5 수준의 스마트폰 Mi-4를 절반 이하 가격으로 출시 ⇨ ’13.1Q 중국 스마트폰 시장 7위 → ’14.2Q 1위 등극

    ** IT와 제조․공정을 융합한 스마트 제조기술로 생산방식과 제품성격이 혁명적 변화

  ⇒ 우리 제조업 재도약을 위한 구조적 혁신과 새로운 전략 필요

  

☐ 이에 지난 6월말 ｢제조업 혁신 3.0 전략*｣을 발표하고, 우리 제조업의 나아갈 방향과 기본 전략을 제시

    * (1.0) 경공업 중심 발전 → (2.0) 조립․장치산업 추격 → (3.0) 융합형 신제조업 선도전략

나. 향후계획 

☐ 旣 발표한 ｢제조업 혁신 3.0 전략｣을 토대로, 관계부처 협업과 민간 의견수렴 통해 수요자 의견을 반영한 대책을 마련

 ⇒ 향후 3년 이내 가시적 성과도출을 위한 범부처 실행대책 (Action plan) 마련 예정 

 < 제조업 3.0 전략 실행대책(Action plan) 추진방향 (예시) > 

| ◇ 스마트 공장 확산, 기업맞춤형 인력양성, 소프트파워 경쟁력 제고 등 우리 제조기업의 혁신역량 제고 ◇ 융합 신제품 시장 창출, 세계선도형 부품소재 개발 등 미래시장을 선도할 성장동력 창출 ◇ 우리 제조업 경영·투자 환경 애로 해소 등 |
| :--- |

| 생활산업 고도화 전략 추진 |
| :--- |

가. 추진 배경

 ☐ 가구, 완구, 주방용품 등 생활산업은 ‘12년 기준 생산 46조원, 수출 73억불, 수입 107억불, 종사자 20만명 수준으로 영세한 편이나,

    * 연평균 증가율(‘03→’12년, %) : (생산) 5.4, (수출) 3.3, (수입) 11.2, (종사자수) △1.4

 ㅇ 최근 라이프 스타일 변화, 소득수준의 증대에 따른 소비패턴의 변화 등으로 고부가가치 시장으로 변화 중

 

 ⇒ 창조적 융합을 통한 획기적 부가가치 창출이 가능한 생활산업의 재도약으로 우리경제의 새로운 성장 모멘텀으로 활용할 필요

나. 향후 계획 

□ 생활산업의 재도약을 통한 창조경제 실현을 위한 ‘생활산업 고도화 전략’ 마련(‘14.10월)

    * 그간 업종별 현장방문 및 간담회를 통한 현황 및 기업수요 파악(~5월)하고, 정책과제 도출 및 생활산업 미래트렌드 전망을 위한 정책연구 수행 

| 2 |  | 창조적 산업생태계 구축 |
| :--- | :--- | :--- |

| First-Mover 전략을 견인할 기획·설계 역량 강화 |
| :--- |

가. 추진 현황

☐ 제조업 혁신을 선도할 수 있는 가치사슬 상위 분야 육성을 위한 ｢두뇌역량우수전문기업(K-BrainPower)｣ 선정제 마련

    * ｢고급두뇌 전문기업 육성방안｣ 발표(`13.12월, 경제관계장관회의)

 ㅇ (전문기업 선정) 2014년 제1차 ｢두뇌역량우수전문기업｣ 선정(18개社)

    * 엔지니어링(5개社), 디자인(5), 임베디드SW(4), 시스템반도체(1), 바이오(3)

 ㅇ (지원제도) 선정된 기업들에 대해 인력*·기술개발**·자금*** 등 종합적인 지원을 우선적으로 제공

    * 설계엔지니어링 분야 해외 우수인재 채용 인건비 지원, 디자이너 해외진출 지원 등

   ** 두뇌역량우수전문기업 전용 R&D 프로그램 마련

  *** 두뇌산업 투자펀드 조성

☐ 기업수요를 반영한 기획·설계 분야 고급인력 양성 추진

 ㅇ 엔지니어링개발연구센터(EDRC), 특성화대학원 설립을 통한 공과대학의 엔지니어링 교육·연구기능 강화

    * 엔지니어링개발연구센터 설립(‘14.6월), 특성화대학원 2개교 신규 선정(’14.6월) 

나. 향후계획 

☐ 창조경제 구현 및 제조업 혁신을 선도할 ｢두뇌역량우수전문기업｣ 추가 선정 및 지속 지원(`14년 누적 40개社, `18년까지 200개社)

☐ 엔지니어링 기반 디자인-기술 융합 고급인력 양성을 위해 선정(`14.9월)한 디자인-기술 융합 대학원(3개)의 전문대학원 신설 추진(`15년)

| 산업기술 R&D의 창의성과 투자효율성 제고를 위한 제도 혁신 |
| :--- |

가. 추진 현황

☐ R&D의 창의성과 투자효율성 제고를 위해 R&D 기획·평가·관리 프로세스 혁신

    * 「산업기술 R&D제도 혁신방안」발표(‘14.6월, 제10차 창조경제위원회)

 ㅇ (창의적 R&D) 품목지정형 과제 본격 도입 및 평가 내실화

    * 품목지정형 과제 : 지정공모와 자유공모의 중간형태로, 과제 기획과 사업 수행자가 일치되고 창의적 연구 가능(‘17년까지 산업부 R&D의 30%까지 확대)

  - 아이디어 중심 개념평가 도입(4쪽 이내), 내실 있는 과제 검토를 위해 사전 서면검토 실시, 토론평가 도입으로 심도있는 평가 실시

 ㅇ (인적자본 투자 확대) 중소·중견기업 및 지식서비스업 R&D 인력에 대한 인건비 지원 강화

    * 인건비 비중 : (‘13) 27.7% → (’17) 40% 목표 (OECD 평균은 46% 수준)

 ㅇ (R&D 투자 효율성 제고) 정부와 민간의 매칭비중을 원천기술형 과제는 높게, 혁신제품형 과제는 낮게 차등화

    * (정부:민간, 원천형/혁신형) 대기업 1:1 / 1:2, 중소기업 3:1 / 2:1

☐ 산업부 R&D 참여기업에게 1년간 우선 실시권을 준 후 그 이후에는 非참여 중소기업이 요청하면 기술 실시 허락

 ㅇ 非참여 중소기업에서 받는 로열티는 정부에 납부하는 기술료 규정에 준하여 적용

    * 예시 : (현행) 일반적으로 매출액의 5% 내외 → (개선) 매출액의 1.25% 이내

 ㅇ 참여기업이 없이 공공연(출연연 등) 단독수행(PBS, 블록펀딩) 하여 창출한 IP는 업종별 단체(협동조합 등)를 통한 회원사에게 실시권 확산(로열티는 상호 합의)

나. 향후 계획 

☐ 산업기술 R&D 제도개선 사항은 관련규정 개정, 미래부 등 他부처 협의를 거쳐 ‘15년부터 시행 추진

☐ 미래부의 국가연구개발사업 관리규정(대통령령)과 우리부 공통운영요령(고시) 동반 개정(～‘15.1분기)

| 창조경제를 뒷받침하는 산업기술기반 구축․활용 |
| :--- |

가. 추진 현황

☐ 혁신산단 등 산업 현장의 R&D 요구에 대응한 전략적 연구시설․장비 구축 추진

 ㅇ 장비 공동활용 수요를 기반으로 사전 기획을 통해 정책적․기술적 타당성이 입증된 기반구축사업을 신규 추진

    * 3D프린팅 제조혁신지원센터, 플렉서블 전자소재 산업기술기반, 헬스케어로봇 실증단지 등

☐ 장비 공동활용 촉진을 위한 통합운영기반 조성

 ㅇ 중소기업 등의 원활한 연구활동에 필요한 연구장비 공동활용을 지원하기 위해 ‘장비 공동이용시스템(e-Tube)’* 개설(’13.11월)

   - 연구기관, 대학 등에 구축된 연구장비 정보를 한 곳에서 검색하고, 필요한 장비는 온라인을 통해 바로 예약․사용

    * ‘14.9월말까지 실적 : (장비등록) 24,370대, (공동활용장비) 15,359대, (e-Tube 방문) 134,576명, (장비이용) 9,268건

 ㅇ 장비 관리․활용의 제도적 기반으로 ｢장비 통합관리요령｣ 제정(‘14.5월)

   - 장비의 기획부터 처분까지 全주기를 e-Tube를 통해 처리토록 절차를 간소화하여 수행기관, 장비사용자 모두에게 편의성 향상을 제공

 ㅇ 공공硏, 대학 등이 보유한 노후장비의 이전․재활용사업 추진

   - 최초로 유휴․불용장비 일제정비사업을 시행, 총 249대를 접수하여 이 중 99대 불용처리, 150대 재활용 추진중*

    * 양수희망기관에 유휴장비 78대 이전 완료 (‘14.2월~8월)

☐ 기술사업화 종합정보망(NTB)을 ‘기술은행’으로 확대·개편

    * 제5차 기술의 이전 및 사업화 촉진 계획 (‘14.4월, 국과심 확정)

 ㅇ 기술은행에서 공급하는 기술의 양과 질을 제고하기 위해 정부 R&D 성과물의 등록을 의무화하도록 법령 개정 추진(‘14.10월∼)

   - 대기업, 사업화 지원기관 등의 적극적인 참여를 위해 기술나눔  업무협약 체결하고, 대기업-中企간 기술나눔행사 추진(2회)

    * 산업부·대기업(삼성전자, 현대·기아차 등 6개)·중견기업(루멘스 등 3개)·사업화 지원기관(KIAT 등 10개) 간 기술나눔 활성화를 위한 업무협약 체결 (‘14.4월) 

나. 향후 계획 

☐ 공공硏이 내부용으로 구축한 단독활용장비 정보를 추가 개방하고, 연구용 특수목적 장비의 범용化 지원(‘15년~)

 ㅇ 또한, 對기업 장비서비스 향상을 위한 장비 공동활용 플랫폼 구축 (노후장비 성능향상, 장비인력 역량강화 등) 신규 추진(‘15년 79억원)

☐ 등록기술 DB의 품질 제고, 공급·수요 연계 강화 등을 내용으로 하는 기술은행 구축 세부계획 마련(‘14.10월) 및 서비스 제공(‘15년 상반기)

 ㅇ 기술은행과 기술거래 지원기관, 정부 지원사업 등과 연계하여 기술거래시장 활성화 및 기술기반의 비즈니스 창출 촉진

| 산업계가 요구하는 인력양성 및 공급 |
| :--- |

가. 추진 현황

☐ 중소․중견기업 등 산업계 수요가 있는 분야별 산업인력을 양성하고, 체계적인 산업계 수요 반영을 위한 기반 강화

    * ｢산업전문인력 역량강화사업(17개 분야)｣ : (‘14) 469억원 → (‘15(안)) 497억원

 ㅇ 중소․중견기업 + 대학원 컨소시엄을 통해 산학 공동으로 연구인력 양성*, 채용과 연계하는 新산학협력 추진(‘14.7월)

   * 학생 공동선발, 기업애로 프로젝트 수행, 프로젝트 성과 중심 학위부여 등

 ㅇ 엔지니어링, 디자인 등 부가가치와 타 산업 파급효과가 높은 소프트파워․융합 전문인력 중점 양성

 ㅇ 관계부처 합동 ｢산업별 인적자원협의체(SC*) 기능 강화방안｣ 수립(산업․교육․고용부, ‘14.8월) → SC를 정부 공동 인프라로 활용

   * SC(Sector Council) : 산업현장의 인력수요 파악, 인적자원 개발정책 등을 지원하는 산업계 단체, 기업, 교육훈련기관 등으로 구성된 산업별 협의체

나. 향후 계획 

☐ 중소․중견기업 인력양성 지원 확대, 관계부처 공동 SC 활용 본격화 등 기업․현장 중심의 인력정책 지속 강화

 ㅇ (新산학협력 추진) 단계적 컨소시엄 확대(‘14년 7개 → ’15년(안) 10개 이상)를 통해 중소․중견기업 연구인력 지원 강화 

 ㅇ (SC 활용) 연내 SC 공동 운영위를 출범․운영 → 산업현장 인력수요의 정부정책 및 사업 반영채널 본격 가동  

   * (SC) 산업별 인력수급 분석 및 인력사업 제시 → (관계부처) 인력사업에 검토․반영

| 중소･중견･대기업간 동반성장 활동 적극 진행 |
| :--- |

가. 추진 현황

□ 2․3차 협력사의 경쟁력을 강화‧지원하는 중소‧중견․대기업간 동반성장 활동 적극 진행

 ㅇ 대기업과 1차 기업이 2․3차 협력사의 생산혁신 지원하는  ｢산업혁신 3.0｣ 활성화

    * (1차년도) 53개 대기업, 15개 중견기업, 12개 공공기관 동참으로 총 1,957개 협력중소기업 지원

    * (효과) 핵심지표(KPI) 51.7% 개선, 재무효과 365억원, 455명 신규채용 등 성과 창출

 ㅇ 대․중소기업간 공동 기술개발, 상품성‧생산성 증진 활동 등으로 부품소재 국산화 등을 진행하는 성과공유제 업계 확산

    * (성과) 도입기업(중견기업 포함) 166개 및 4,456개 과제 발굴(’14.9월말 기준)

    * (효과) 성과공유 완료과제당 대기업 2.4억원, 중소기업 2.7억원의 이익발생(전경련 실태분석, ‘13.6월)

☐ 유통법의 현장정착 및 유통분야 상생협력 도모

 ㅇ 지자체별 “유통업상생발전협의회*(’13.4월 유통법)”를 구성․운영 독려

    * 지역 대․중소 유통 대표 각 2인 등으로 구성(회장: 부시장)되며, 지역의 유통 상생․발전과 관련된 사항을 협의(분기별 1회 이상 개최 원칙)

 ㅇ “유통산업연합회*(‘13.3월 구성)”를 통해 유통분야 상생협력 유도

    * 유통갈등 해결을 위해 체인스토어․백화점․편의점․프랜차이즈협회, 상인연합회, 수퍼연합회 등으로 구성한 민간협의체로 산업부는 운영위원으로 참여

   - 연합회를 통해 대-중소 유통협단체간 공동구매협력사업 합의(‘13.10월) 및 협력 MOU 체결(’13.11월)을 유도하고, 후속조치 독려

나. 향후 계획 

□ 2․3차 협력사의 경쟁력 제고, 참여강화 등 상생분야 확대

 ㅇ (산업혁신 3.0) 2차년도(’14.9월~)부터 ICT 융합 스마트공장 보급, 기술컨설팅 등 보다 심화된 지원 추진

 ㅇ (성과공유제) 서비스업으로 적용범위 확대, 1차(중견기업) 중심의 성과공유제 자율확산 적극 추진

☐ 유통상생 지속 유도

 ㅇ 추가적인 유통 상생모델을 발굴․실행하고, “유통업상생발전협의회” 구성․운영 등에 대해 지속 모니터링

| 3. 개방형 통상정책을 통한 경제협력 활성화 |
| :--- |

| 대외개방형 통상정책 지속 추진   글로벌 비즈니스를 위한 맞춤형 경제협력 활성화 |
| :--- |

| 1 |  | 대외개방형 통상정책 지속 추진 |
| :--- | :--- | :--- |

| 전략적 FTA 네트워크 구축 |
| :--- |

가. 추진 현황

□ 아태지역 경제통합 핵심축(linchpin) 역할 등 대외환경 변화 등을 감안, 국익을 극대화*하는 방향으로 FTA 네트워크 구축

    * 통상절차법상 국회와 정보 적극 공유, 업계․전문가 등과 상시 소통 강화

 ㅇ 한-호주(‘13.12월)･한-캐나다 FTA(’14.3월)는 타결 이후 비준동의안 국회제출(‘14.9월,10월), 한-터키 FTA 서비스투자협정 실질 타결(’14.7월)

    * (호주) 경쟁국인 일본(‘14.4월)보다 먼저 타결, (캐나다) 아시아 국가중 최초,

      (터키) 최초로 서비스․투자 분야를 포함하는 포괄적 FTA 체결

 ㅇ 한-중/한-베트남 FTA는 본격 상품양허 및 협정문 협상을 추진중이며, 한-뉴 FTA는 상품양허 관련 핵심쟁점 논의중

나. 향후 계획

□ 우리기업의 시장진출을 위한 전략적 FTA 추진

 ㅇ (중점 추진) 중국․베트남․뉴질랜드 등 협상시 실질적 진전을 달성하여 연내 FTA 타결을 위한 토대를 마련

   - (중국) 거대시장 수출 및 투자 선점을 위해 내용의 충실성에 중점

    * 한-중 정상회담 (’14.7월)시 ‘한-중 FTA 연내 타결을 위한 노력 강화’에 합의

   - (베트남) 상생형 FTA 성공모델 창출을 위해 협상 가속화

   - (뉴질랜드) 시장개방 및 이익균형 확보 방안 중심 논의 진전

 ㅇ (국회 비준) 한-호주/한-캐나다 FTA의 연내 국회 비준동의 요청

    * (한-호 FTA) ‘14.10.1, 의회절차 완료

      (한-캐 FTA) 캐나다는 의회심의에 기제출(‘14.6월), 조속한 절차 완료에 강한 의지

 ㅇ (TPP 입장 정리) TPP 협상 진전 동향을 긴밀히 모니터링하고 예비 양자협의를 추진하면서 이해관계자 의견수렴 등 국내절차 추진

| WTO 협상 등 다자 협상에 적극 참여 |
| :--- |

가. 추진 현황

□ 글로벌 무역자유화 및 규범제정을 위한 다자간 논의에 적극 참여

 ㅇ (무역원활화협정) 제9차 WTO 각료회의(‘13.12월, 발리)시 타결된 무역원활화협정 후속조치 추진

    * 우리나라는 무역원활화 협정상 모든 의무를 A의무(협정발효시 즉시 이행)로 분류하여 WTO에 통보(’14.5.28)

 ㅇ (복수국간 협상) 서비스, IT, 환경 분야에서 진행 중인 WTO 복수국간 협상에 참여

    * TISA(서비스협정) 협상 : 미‧EU‧일 등 23개국 참여, 규범‧양허협상 병행으로 높은 수준의 시장개방 추진

    * ITA(정보기술협정) 확대협상 : 미‧EU‧일‧중 등 28개국 참여, 미-중간 타협안 마련을 통한 협상 재개노력 지속 중

    * EGA(환경상품협정) 협상 : 미‧EU‧일‧중 등 14개국 참여하여 ’14.7월 출범, 우리나라는 비공식 참여 중(국회보고 후 공식 참여 예정)

 ㅇ (쌀 관세화) 국회 보고 후 WTO에 쌀 양허표 수정안 제출('14.9.30)

나. 향후 계획

□ 다자간 논의 적극 참여․대응을 통한 구체적 성과도출 추진

 ㅇ (무역원활화협정) 회원국들과 공조하여 협정의 조속이행을 추진하고, WTO 포스트 발리 작업계획에 참여

 ㅇ (복수국간 협상) 분야별 WTO 복수국간 협상 진전 및 타결에 기여함으로써 우리 기업의 수출기반 확충

 ㅇ (쌀 관세화) 관세화 이행(’15.1.1～)을 위한 WTO 검증절차 대응

    * WTO 회원국 검증기간(10～12월) 중 이의제기국이 있을 경우 이의제기국과 협의를 통해 WTO 인증(certification) 추진

 ㅇ (다자협력체) APEC‧OECD‧G20 등에서 에너지‧산업과 연계한 경제‧통상 의제 발굴* 및 논의에 적극 참여

    * APEC에서 우리가 제안한 ‘주요 산업에서의 중소기업의 GVC(글로벌 가치사슬) 참여 촉진 사업’이 회원국들의 승인을 얻어 내년부터 본격 추진 예정

| 2 |  | 글로벌 비즈니스를 위한 맞춤형 경제협력 활성화 |
| :--- | :--- | :--- |

가. 추진 현황

□ 주요국과의 정상외교, 산업협력 등을 활용한 우리기업의 비즈니스 기회 확대

 ㅇ (정상외교 포털) 글로벌 비즈니스 활성화 지원을 위해「정상외교 경제활용포털」구축･운영(‘14.1월)

 ㅇ (경제사절단) 우수 중소‧중견기업의 해외시장 진출 기회 확충* 및 사전기획부터 사후관리까지 경제사절단 전방위 지원 강화**

    * 사절단 중 중소‧중견기업 비중 : 인도(52%, ‘14.1월), 중앙아(63%, ’14.6월)

   ** 사절단 개편방안 마련(‘14.7월) : 사전기획을 통한 순방국별 전략 분야 및 아젠다 도출, 사절단 참여 희망기업 DB 구축, 현지행사 다양화 및 사절단 성공후기 공유․확산 등

나. 향후 계획

□ 신흥시장과 경제협력 활성화를 통한 우리기업의 해외진출 지원

 ㅇ (중앙아) ｢민관 중앙아 경제협력위원회*(‘14.9월～)｣를 통한 상생의 경협기반 구축

    * 국가별 실무위 및 분야별 자문위 구성, 경제단체별(무협, 대한상의, 전경련) 중점 협력국가 분담(공동위원장 : 산업부 장관, 무역협회 회장)

 ㅇ (아프리카) ｢한-아프리카 산업협력 포럼(‘14.10월, 서울)｣ 등을 활용, 전략적 협력방안 도출

    * 한-아프리카 산업협력 강화 방안 논의, 플랜트 분야 유망 프로젝트 발굴, 아프리카 시장 유통채널 확충 등 

 ㅇ (아세안) ｢한-아세안 특별정상회의(‘14.12월, 부산)｣를 계기로 교역·투자 확대 기반 마련

    * 한-아세안간 교역비전 발표, Business Council 신설, FTA 추가자유화 논의 등

 ㅇ (중남미, 유럽) 국가별 산업․자원협력위를 통한 플랜트․자원개발 협력 확대, 선진 산업기술 분야 창조경제 파트너쉽 구축

| 4. 안정적인 에너지시스템 구축 |
| :--- |

| 에너지신산업 육성   안전 최우선의 원전정책 추진       에너지공기업 등 공공기관 정상화 지속 추진      지속가능한 에너지정책 추진 |
| :--- |

| 1 |  | 에너지신산업 육성 |
| :--- | :--- | :--- |

가. 추진 현황

□ ICT 기반 에너지수요관리 정책('13.8월) 발표 후, 기업별로 이와 관련된 투자를 추진 중

    * (한전) ‘17년까지 전력주파수 조정용 에너지저장장지 6,250억원 투자 추진('13.10)

    * (14개 전력다소비기업) '17년까지 72MW 설비의 ESS 투자 추진(‘14.6)

□ 이를 기반으로 민간기업의 창의적인 투자를 유도하고, 신산업을 활성화하기 위하여 ｢에너지신산업 창출방안｣ 발표(‘14.7월)

    * 금년 초부터 민관합동 TF를 구성하여 대표적인 에너지신사업 모델을 발굴

 ㅇ 에너지신산업 대토론회(‘14.9월)를 통하여 에너지신산업 분위기 확산·기업참여를 촉진하고 향후 신산업 추진방향 제시

나. 향후계획

□ 에너지신산업 활성화를 위한 제도개선

 ㅇ 신산업 분야 진입규제는 Positive 방식(원칙적 금지, 예외적 허용)에서 Negative 방식(원칙적 허용, 예외적 금지)로 전환 추진

    * (예시) 지능형전력망 사업자가 자본금·인력 등 자격요건과 등록 없이도 자격을 갖추도록 요건 완화

 ㅇ 전기소비 감축도 자원으로 인정하고 거래할 수 있는 수요자원 거래시장을 차질없이 개설 (‘14.11월)

 ㅇ 에너지저장장치(ESS)․전기차에 저장된 전력을 전력시장과 한전을 통해 거래할 수 있도록 제도개선 (‘14년말)

    * (대용량 ESS) 전력거래소가 운영하는 전력 거래시장에 참여 허용  
 (소용량 ESS․전기차) 소형 신재생발전과 동일하게 직접 한전으로 역판매

□ 초기시장 창출과 민간투자 지원

 ㅇ 에너지저장장치 투자활성화를 위하여 맞춤형 요금제 도입 

    * 전기요금이 낮은 시간대에 충전, 전기요금이 높을 때 저장전력 활용 유도

 ㅇ 전기차 보급확대를 위해 공공기관 전기차 구매 의무화(‘15.1월)와 전기차 배터리리스 시범사업*(’15년 하반기, 제주도 택시·버스 대상) 추진

    * 소비자는 배터리 관리부담과 중고차 가치 불안감 해소, 정부는 보조금 부담완화

 ㅇ 신재생에너지 + ESS 융합 설비에 대해 신재생 공급인증서(REC) 가중치도 우대 (‘15.3월 시행)

□ 에너지신산업 기술개발과 해외진출 지원

 ㅇ 시장·업계 수요를 반영하여 ICT·제조업 등 에너지신산업 기술 간 융복합 혁신기술* 과제 발굴·추진 (‘14.10월~)

    * 정보통신(ICT), 자동차, 신재생에너지 하이브리드 등 산업간 융합기술 개발

  - 시장 조기진입을 위한 R&D 모델 발굴, 중소기업 R&D 이후 사업화 촉진을 위한 컨설팅·인력양성 등 패키지 지원(‘15년~)

 ㅇ 신재생에너지 분야 중소기업의 해외진출을 지원하기 위하여 금융, 마케팅 지원체계 강화

    * 수출초보기업 무역보험 특례도입, 해외진출 중소기업에 대한 융자사업 신설

  - 해외진출 초기부터 현지실증에 이르는 全주기 지원체계 구축

   * 현장 밀착지원을 위한 수출지원자문단, 해외시장분석 TF 가동(‘14.10월～)

| 2 |  | 안전 최우선의 원전정책 추진 |
| :--- | :--- | :--- |

가. 추진 현황

□ 원전의 안전 운영을 위해 후쿠시마 후속대책, 원전비리 근절대책 등을 철저히 이행하고 사후관리 강화

    * 계획예방정비 확대(30일 → 35일 이상), ’11～’15년간 1.1조원 안전 투자 등

    * 원전공기업 퇴직자 재취업 금지, 구매규격 사전공개, 제3기관 재검증

□ 사용후핵연료 공론화위원회 출범(‘13.10월) 이후 국민 의견수렴 전개 중

    * 본회의(24회), 간담회(15회), 토론회(15회), 타운홀 미팅(1회), 인식도 조사(2회) 등

□ ‘09년 수주한 UAE 원전 건설은 지난 5월 1호기 원자로를 설치하고, 9월에는 3․4호기 건설허가를 취득하는 등 순조롭게 추진중

    * ’17.5월 1호기를 시작으로 매년 한 호기씩 준공하여 ’20년 4호기 준공 예정

나. 향후계획

□ 원전 건설․운영의 안전 최우선 원칙 준수 

 ㅇ (안전관리) 예방적 현장점검, 안전투자 확대 등을 통해 전체 원전업계의 안전․청렴 기반의 조직 문화 조성* 

    * 안전취약 분야 선제적 발굴․조치, 한수원 의식개혁, 안전 캠페인 전개 등

   - 아울러, 원전 공공기관의 안전․비리예방 경영활동을 법률로써 제도화*하여 철저히 관리․감독

    * ｢원전사업자 관리․감독 법｣(‘13.12월 정수성의원 입법 발의) 법안소위 계류중

 ㅇ (계속운전) 안전성을 전제로 경제성, 지역수용성 등을 종합 고려하여 계속운전 여부 결정

    * (월성1호기) KINS 심의완료(9.30), 원안위전문위원회 개최(10.2) 등 원안위 심의중

    * (고리1호기) 한수원이 작성중인 안전성평가보고서를 토대로 경제성․수용성을 고려하여 향후 규제기관 신청 여부 결정

 ㅇ (신규건설) 현재 확정되어 있는 원전 11기(건설중 5기, 계획중 6기)는 안전성을 토대로 추진 

    * 제2차 에너지기본계획(‘14.1월)에 따라 ’35년까지 원전비중 29% 목표

□ 방사성폐기물의 안전한 관리 기반 마련

 ㅇ (경주방폐장) 원안위 운영허가 취득, ’15년부터 본격 운영 추진

   - 방폐장 건설과 관련한 공사는 ’14.6월말 모두 완료, 현재 원안위의 사용전검사 등 인허가절차 진행중

 ㅇ (사용후핵연료) 공론화委에서 광범위한 의견수렴을 거쳐 권고안을 제출(’14.末)할 예정이며, 이를 토대로 관리대책 수립 추진(’15년)

   - 공론화委는 간담회·공론조사·토론회·대국민 설문조사 등 폭넓은 의견수렴과 사용후핵연료 관련 권고안 논의를 본격 진행중

□ 원전에 대한 대국민 인식 제고

 ㅇ (원전수출) UAE 원전 건설의 성공적 추진 및 해외진출 확대

   - UAE 원전의 차질 없는 건설과 더불어 준공후 운영지원, 인력 교류, 관련산업 육성 등으로 포괄적인 동반자 관계 강화

   - 베트남, 영국, 체코 등 원전 도입국별 특화된 수주활동 전개를 통해 원전 수주 확대

    * (베트남) 예비타당성조사 수행(～‘14.12월), (영국) 민자원전사업 참여를 위한 인식제고활동 추진 등

 ㅇ (지역상생) 원전 온배수 활용 등 지역주민들이 체감할 수 있는 원전지역 상생협력 방안 수립․추진(‘14년 하반기)

    * 실질적 소득증대 창출 가능 지원책 ⇨ 주민소득 증대 ⇨ 지역 수용성 제고

 ㅇ (정보제공) 원전의 안전성, 경제성, 원전비리 혁신성과 등에 대한 정확한 정보를 국민에게 제공하여 원전이해 증진

    * 국민 체감을 위해 안전홍보 캠페인 추진(9∼12월) 및 원전에 대한 개방․견학 확대

| 3 |  | 에너지공기업 등 공공기관 정상화 지속 추진 |
| :--- | :--- | :--- |

가. 추진 현황

□ (부채감축) 11개 중점관리대상기관*의 총 부채를 ‘17년 185.4조원 규모로 축소하고 부채비율을 159% 수준으로 감축 추진

    * 한전, 한수원, 발전 5사, 가스ㆍ석유ㆍ광물ㆍ석탄공사

    * 11개 에너지 공기업 총 부채비율(계획) : (’14년)172.4%→(’17년)159.5%

  ㅇ ‘14.8월말 기준으로 7조 1,783억원*의 부채를 절감, ’14.8월말까지의 목표(4.1조원)대비 초과 달성(달성률 173%)

    * 중간평가(‘14.9～10) 실적 인정기준 적용시(계획대비 초과감축 및 미계획 감축분 제외) ‘14.8월말 기준 4.1조원 감축(목표대비 98%)

□ (방만경영 개선) 과도한 복리후생*을 공무원 수준으로 조정하고 1인당 복리후생비를 평균 300만원 이하**로 개선 추진

    * ①퇴직금, ②교육비ㆍ보육비, ③의료비, ④경조사비/기념품, ⑤휴가ㆍ휴직제도, ⑥복무형태, ⑦유가족 특별채용, ⑧경영․인사

   ** (1인당 복리후생비) ‘13년 443만원→ ’14년 286만원(△157만원, △35.5%)

 ㅇ ‘14.9월말 기준 중점관리대상 16개 중 15개 기관이 방만경영 개선완료, 중점관리外 25개 중에서는 22개 기관이 개선완료

    * (미완료 4개 기관) 한국전력기술(중점관리), 산업기술시험원, 한전KDN, 산업단지공단

나. 향후 계획

□ 연내 부채감축과 방만경영 개선 목표 달성 추진

 ㅇ 금년 12월까지 공기업 부채를 6.5조원 추가 감축할 계획

 ㅇ 방만경영 개선 미완료 4개 기관에 대해서는 조속히 완료토록 독려

□ 주도면밀한 정상화 이행점검 

 ㅇ 매월 정상화 실적점검회의를 개최하여 지속적으로 강도 높은 실적 점검과 이행 독려

    * 정상화계획 수립(‘14.2월) 이후 매월 1회 이상 점검회의 개최중

 ㅇ 정상화 실적을 기관장 인사와 임직원 성과급에 반영함으로써 이행력 확보

| 4 |  | 안전하고 지속가능한 에너지 공급체계 구축 |
| :--- | :--- | :--- |

가. 추진 현황

□ 금년 여름에는 원전비리 척결, 발전소 조기준공 등으로 전력수급이 원활*하였으며, 겨울에도 적정 예비력 확보에 노력

    * 여름 피크시 전력수급(만kW) : (‘13) 수요 8,008만kW / 공급 7,811만kW(대책전)→ (’14) 수요 7,605만kW / 공급 8,413만kW

□ 세월호 사고 후, 산업부 소관 주요시설에 대한 총체적 안전점검 실시(4.28〜5.16), 미흡사항 개선과 안전 인프라 확충 추진  

  * (공기업) 전력·가스 등 10개 기관장 책임하에 점검, 특별예산 783억원 편성·안전조직 확대유도  
(민간) 정부합동으로 가스-전기시설·산업단지 점검, 취약요소 정비 및 안전 정상화과제 발굴·개선

나. 향후계획

□ 전력·가스·석유 등 전통에너지원의 안정적·효율적 수급체계 구축

 ㅇ (전력) 밀양 송전선로 건설* 등 적기에 송전시설을 구축하고, 안정적인 송전망 운영을 위해 전력계통 신뢰도감독기구 설립

    * 신고리-북경남, 신울진-신경기, 북당진-신탕정

 ㅇ (가스) 국내 최초 북미산 셰일가스 도입(‘17~’37년간 年 280만톤)을 승인하고 신규 LNG선(6척) 발주(‘14.8월)

 ㅇ (석유) 미국산 컨덴세이트 수입 등 원유도입선을 다변화하고, 석유산업 선진화를 위해 동북아 오일허브 구축을 추진

    * 상업용 저장시설 확보, 블렌딩 규제완화, 정제시설의 보세공장 전환 등

 ※ 각 에너지원별 중장기 계획 수립(‘14말～’15년간 마련) : 제7차 전력수급기본계획, 제12차 천연가스 장기수급계획, 제4차 석유비축계획 등

 ㅇ (자원개발) UAE․이라크 쿠르드 유전개발 등 핵심사업에 역량을 집중하고, 투자 부실 방지를 위해 공기업 투자프로세스 개선

   - 공기업은 핵심사업에 역량을 집중하고 신규사업은 탐사위주로 추진, 개발․생산 단계는 민간기업․투자자의 참여를 활성화

   * 해외자원개발펀드 투자위험보증 규모확대: (‘14.9월) 2.2조원 → (’17년) 4조원 (목표)

   - 투자리스크위원회 신설·외부전문가 참여 의무화 등으로 공기업 투자심의를 강화하고, 프로젝트 이력제 등 운영하여 책임성 제고

□ 국민이 안심할 수 있는 에너지시설 안전관리

 ㅇ (관리체계) 산업부의 ｢에너지안전전문委｣, 각 공기업의 ｢안전관리委｣ 중심으로 상시적 에너지안전 관리체계 운영(계획-시행-평가 全주기)

 ㅇ (제도개선) 비정상적 제도·관행은 법령개정 등 신속히 정상화

   * 독성가스, 도시가스배관, 노후 가스시설에 대하여 안전관리 강화

 ㅇ (기술·인프라) 안전기술 R&D(‘14년 가스분야 85억원), 인프라 확충*등을 통해 안전관리 고도화 

   * 가스화재ㆍ폭발 성능평가센터(‘12.∼’16년), 독성가스 중화처리센터(‘14.∼’17년) 구축

□ 취약계층 보호를 위한 에너지복지 확충

 ㅇ (에너지 접근성 제고) 저소득층 에너지 지원을 위해 에너지바우처를 ‘15년 동절기(’15.12월)부터 지원, 에너지효율개선사업 지속 추진

   * 중위소득 40% 이하 노인·아동·장애가구 중심으로 동절기 3개월간 평균 10만원 내외 지원

 ㅇ (시설 개선) 도시가스 미공급 농어촌 지역에 대하여 소형저장탱크 보급 확대, 쪽방촌 전기시설 및 서민층 가스시설 무료 개보수* 지원

   * (전기) 소규모 무허가 거주시설(4,630호) 개보수(‘13.∼’15), (가스) 고무호스→금속배관, 40만가구(‘11.～’15) 

